'Journal to Cycle All Part Files in a Tree of Folders
Option Strict On
Imports System
Imports System.IO
Imports System.Collections

Imports NXOpen
Imports NXOpenUI
Imports NXOpen.uf
 
Module Cycle_Files_and_Folders
    Dim theSession As Session = Session.GetSession
    Dim LW As ListingWindow = theSession.ListingWindow
    Dim theUI As UI = UI.GetUI

    Dim workPart As Part = theSession.Parts.Work
    Dim displayPart As Part = theSession.Parts.Display

    Dim nDirectories As Integer = 0
    Dim nTotalPartFiles As Integer = 0

    Sub Main()
        Try
            LW.Open()
            LW.WriteLine("Cycle All Parts in a Folder Tree")
            LW.WriteLine("Start Time: " & CType(TimeOfDay(), String))

            'Process all Directories

            walkDirectories(Directory.GetCurrentDirectory)
            
            LW.WriteLine("Directories Scanned: " & nDirectories)
            LW.WriteLine("Total Part Files Scanned: " & nTotalPartFiles)
            LW.WriteLine("Stop Time: " & CType(TimeOfDay(), String))
        Catch ex As NXException
            LW.WriteLine("Cycle Files and Folders Error: " & ex.Message)
        End Try
    End Sub

    '********************************************************************************
    'Process a Directory

    Sub walkDirectories(ByVal directoryPath As String)
        Try
            nDirectories = nDirectories + 1

            LW.WriteLine(nDirectories & " " & directoryPath)

            'Process All Parts in the Given Directory
            processParts(directoryPath)

            'Process All Sub-Directories

            For Each subDirectory As String In Directory.GetDirectories(directoryPath)
                walkDirectories(subDirectory)
            Next subDirectory
        Catch ex As Exception
            LW.WriteLine("Directory Scan Error: " & ex.Message)
        End Try
    End Sub

    '***************************************************************************
    'Process All Parts in a Directory

    Sub processParts(ByVal directoryPath As String)
        Try
            Dim nPartFiles As Integer = 0

            For Each fileName As String In Directory.GetFiles(directoryPath, "*.prt")
                nPartFiles = nPartFiles + 1
                nTotalPartFiles = nTotalPartFiles + 1

                LW.WriteLine("   " & nPartFiles & " " & Path.GetFileName(fileName))

                'the following lines have not been tested but show the methods to open and close parts
                'part1 = theSession.Parts.OpenDisplay(fileName, partLoadStat)
                'theSession.Parts.CloseAll(BasePart.CloseModified.CloseModified, partCloseStat)
            Next fileName
        Catch ex As Exception
            LW.WriteLine("Part Scan Error: " & ex.Message)
        End Try
    End Sub

    '***************************************************************************
    'Process All Text Files in Directory

    Sub processFiles(ByVal directoryPath As String)
        Try
            Dim nPartFiles As Integer = 0

            For Each fileName As String In Directory.GetFiles(directoryPath, "*.txt")
                nPartFiles = nPartFiles + 1
                nTotalPartFiles = nTotalPartFiles + 1

                LW.WriteLine("   " & nPartFiles & " " & Path.GetFileName(fileName))

                Dim myReader As StreamReader
                myReader = File.OpenText(fileName)

                Dim currentLine As String

                Do While Not myReader.EndOfStream
                    Try
                        currentLine = myReader.ReadLine
                        LW.WriteLine(currentLine)
                    Catch ex As EndOfStreamException
                        LW.WriteLine(ex.Message)
                        Exit Do
                    End Try
                Loop

                'the following lines have not been tested but show the methods to open and close parts
                'part1 = theSession.Parts.OpenDisplay(fileName, partLoadStat)
                'theSession.Parts.CloseAll(BasePart.CloseModified.CloseModified, partCloseStat)
            Next fileName
        Catch ex As Exception
            LW.WriteLine("Part Scan Error: " & ex.Message)
        End Try
    End Sub
End Module
